import { Construct } from 'constructs';
import { Alarm, CreateAlarmOptions, IAlarmAction, IMetric } from 'aws-cdk-lib/aws-cloudwatch';
import { ILogGroup, MetricFilter } from 'aws-cdk-lib/aws-logs';
import { Duration } from 'aws-cdk-lib';
import { ITopic } from 'aws-cdk-lib/aws-sns';
/**
 * Properties for LogAlarm
 */
export interface LogAlarmProps extends CreateAlarmOptions {
    /**
     * The log group to watch.
     *
     * If not set, the alarm and metric are not created.
     */
    readonly logGroup: ILogGroup;
    /**
     * The log pattern to match.
     */
    readonly pattern: string;
    /**
     * The namespace of the metric to emit.
     */
    readonly metricNamespace?: string;
    /**
     * The name of the metric to emit.
     *
     * Default value is the id passed into the Construct.
     */
    readonly metricName?: string;
    /**
     * The period over which statistics are applied
     *
     * Default is 5 minutes.
     */
    readonly metricPeriod?: Duration;
}
/**
 * Create a CloudWatch Alarm to trigger when log patterns are matched
 */
export declare class LogAlarm extends Construct {
    readonly alarm: Alarm;
    readonly filter: MetricFilter;
    readonly metric: IMetric;
    constructor(scope: Construct, id: string, props: LogAlarmProps);
    addAlarmActions(actions?: IAlarmAction[]): LogAlarm;
    addAlarmTopics(topics?: ITopic[]): LogAlarm;
}
