import { StandardFunctionProps } from "./standard-function";
import { Function, Runtime } from "aws-cdk-lib/aws-lambda";
import { Construct } from "constructs";
import { MonitoringFacade } from "cdk-monitoring-constructs";
import { LogAlarm } from "../../aws-cloudwatch";
export interface PythonFunctionProps extends StandardFunctionProps {
    /**
     * The runtime environment for the Lambda function. Must be one of the Python runtimes.
     *
     * @default Runtime.PYTHON_3_9
     */
    readonly runtime?: Runtime;
    /**
     * Location on the filesystem the Lambda assets are found.
     *
     * Example: path.join(__dirname, '..', 'mylambda')
     */
    readonly entry: string;
    /**
     * File containing the handler.
     *
     * @default 'index.py'
     */
    readonly index?: string;
    /**
     * Exported handler function
     *
     * @default 'handler'
     */
    readonly handler?: string;
}
export declare class PythonFunction extends Construct {
    static readonly DEFAULT_LOG_METRIC_PATTERN = "\"[ERROR]\"";
    static readonly DEFAULT_LOG_INSIGHTS_PATTERN = "\\[ERROR\\]";
    readonly monitoring: MonitoringFacade;
    readonly function: Function;
    readonly criticalLogAlarm: LogAlarm;
    readonly warningLogAlarm: LogAlarm;
    constructor(scope: Construct, id: string, props: PythonFunctionProps);
}
